@@ -9,8 +9,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.MigrationHubStrategyRecommendations 1.22.0\nVersion:        "
-        " 1.22.0.post1\nBuilder version: 7.5.9\nDocs:           "
+        "Type annotations for boto3.MigrationHubStrategyRecommendations 1.22.8\nVersion:        "
+        " 1.22.8\nBuilder version: 7.5.12\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_migrationhubstrategy//\nBoto3 docs:"
         "     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/migrationhubstrategy.html#MigrationHubStrategyRecommendations\nOther"
@@ -23,7 +23,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.22.0.post1")
+    print("1.22.8")
 
 
 def main() -> None:
